@@ -1,4 +1,4 @@
-# $Id: Common.pm,v 1.2 1997/05/24 22:08:32 aas Exp $
+# $Id: Common.pm,v 1.5 1997/10/13 19:43:57 aas Exp $
 #
 package HTTP::Request::Common;
 
@@ -14,7 +14,9 @@ require Exporter;
 require HTTP::Request;
 use Carp();
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+
+my $CRLF = "\015\012";   # "\r\n" is not portable
 
 sub GET  { _simple_req('GET',  @_); }
 sub HEAD { _simple_req('HEAD', @_); }
@@ -45,7 +47,8 @@ sub POST
 	if (lc($ct) eq 'multipart/form-data') {    #XXX: boundary="..."
 	    my $boundary;
 	    ($content, $boundary) = form_data($content, $boundary);
-	    $ct = qq(multipart/form-data; boundary="$boundary");
+	    $boundary = qq("$boundary") if $boundary =~ /\W/;
+	    $ct = qq(multipart/form-data; boundary=$boundary);
 	} else {
 	    # We use a temporary URI::URL object to format
 	    # the application/x-www-form-urlencoded content.
@@ -103,6 +106,7 @@ sub form_data   # RFC1867
 		local(*F);
 		local($/) = undef; # slurp files
 		open(F, $file) or Carp::croak("Can't open file $file: $!");
+		binmode(F);
 		$content = <F>;
 		close(F);
 		unless ($ct) {
@@ -119,11 +123,11 @@ sub form_data   # RFC1867
 		$content = $h->header("Content");
 		$h->remove_header("Content");
 	    }
-	    push(@parts, "Content-Disposition: $disp\n" .
-                         $h->as_string .
-                         "\n$content");
+	    push(@parts, "Content-Disposition: $disp$CRLF" .
+                         $h->as_string($CRLF) .
+                         "$CRLF$content");
 	} else {
-	    push(@parts, qq(Content-Disposition: form-data; name="$k"\n\n$v));
+	    push(@parts, qq(Content-Disposition: form-data; name="$k"$CRLF$CRLF$v));
 	}
     }
     return "" unless @parts;
@@ -143,9 +147,9 @@ sub form_data   # RFC1867
 	last;
     }
 
-    my $content = "--$boundary\n" .
-                  join("\n--$boundary\n", @parts) .
-                  "\n--$boundary--\n";
+    my $content = "--$boundary$CRLF" .
+                  join("$CRLF--$boundary$CRLF", @parts) .
+                  "$CRLF--$boundary--$CRLF";
     wantarray ? ($content, $boundary) : $content;
 }
 
@@ -154,7 +158,9 @@ sub boundary
 {
     my $size = shift || 1;
     require MIME::Base64;
-    MIME::Base64::encode(join("", map chr(rand(256)), 1..$size*3), "");
+    my $b = MIME::Base64::encode(join("", map chr(rand(256)), 1..$size*3), "");
+    $b =~ s/[\W]/X/g;  # ensure alnum only
+    $b;
 }
 
 1;
