@@ -1,10 +1,9 @@
-# $Id: RobotUA.pm,v 1.13.2.1 1998/10/12 12:01:44 aas Exp $
+# $Id: RobotUA.pm,v 1.10 1997/11/06 19:46:34 aas Exp $
 
 package LWP::RobotUA;
 
 require LWP::UserAgent;
 @ISA = qw(LWP::UserAgent);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.13.2.1 $ =~ /(\d+)\.(\d+)/);
 
 require WWW::RobotRules;
 require HTTP::Request;
@@ -47,9 +46,11 @@ special agent will make sure you are nice.
 =head1 METHODS
 
 The LWP::RobotUA is a sub-class of LWP::UserAgent and implements the
-same methods. In addition the following methods are provided:
+same methods.  The use_alarm() method also desides whether we will
+wait if a request is tried too early (if true), or will return an error
+response (if false).
 
-=over 4
+In addition these methods are provided:
 
 =cut
 
@@ -64,7 +65,7 @@ same methods. In addition the following methods are provided:
 #
 
 
-=item $ua = LWP::RobotUA->new($agent_name, $from, [$rules])
+=head2 $ua = LWP::RobotUA->new($agent_name, $from, [$rules])
 
 Your robot's name and the mail address of the human responsible for
 the robot (i.e. you) is required by the constructor.
@@ -100,12 +101,12 @@ sub new
 }
 
 
-=item $ua->delay([$minutes])
+=head2 $ua->delay([$minutes])
 
 Set the minimum delay between requests to the same server.  The
 default is 1 minute.
 
-=item $ua->use_sleep([$boolean])
+=head2 $ua->use_sleep([$boolean])
 
 Get/set a value indicating wether the UA should sleep() if request
 arrive to fast (before $ua->delay minutes has passed).  The default is
@@ -130,7 +131,7 @@ sub agent
 }
 
 
-=item $ua->rules([$rules])
+=head2 $ua->rules([$rules])
 
 Set/get which I<WWW::RobotRules> object to use. 
 
@@ -144,7 +145,7 @@ sub rules {
 }
 
 
-=item $ua->no_visits($netloc)
+=head2 $ua->no_visits($netloc)
 
 Returns the number of documents fetched from this server host. Yes I
 know, this method should probably have been named num_visits() or
@@ -161,7 +162,7 @@ sub no_visits
 *host_count = \&no_visits;  # backwards compatibility with LWP-5.02
 
 
-=item $ua->host_wait($netloc)
+=head2 $ua->host_wait($netloc)
 
 Returns the number of seconds (from now) you must wait before you can
 make a new request to this host.
@@ -196,6 +197,7 @@ sub simple_request
 	# fetch "robots.txt"
 	my $robot_url = $request->url->clone;
 	$robot_url->path("robots.txt");
+	$robot_url->params(undef);
 	$robot_url->query(undef);
 	LWP::Debug::debug("Requesting $robot_url");
 
@@ -224,7 +226,7 @@ sub simple_request
 	  &HTTP::Status::RC_FORBIDDEN, 'Forbidden by robots.txt';
     }
 
-    my $netloc = $request->url->host_port;
+    my $netloc = $request->url->netloc;
     my $wait = $self->host_wait($netloc);
 
     if ($wait) {
@@ -248,7 +250,7 @@ sub simple_request
 }
 
 
-=item $ua->as_string
+=head2 $ua->as_string
 
 Returns a text that describe the state of the UA.
 Mainly useful for debugging.
@@ -268,17 +270,12 @@ sub as_string
 
 1;
 
-=back
-
 =head1 SEE ALSO
 
 L<LWP::UserAgent>, L<WWW::RobotRules>
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright 1996-1997 Gisle Aas.
-
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+Gisle Aas E<lt>aas@sn.no>
 
 =cut
