@@ -1,5 +1,5 @@
 #
-# $Id: Simple.pm,v 1.28.2.1 1998/09/11 11:03:20 aas Exp $
+# $Id: Simple.pm,v 1.24 1997/10/16 11:13:08 aas Exp $
 
 =head1 NAME
 
@@ -35,7 +35,7 @@ The following functions are provided (and exported) by this module:
 
 The get() function will fetch the document identified by the given URL
 and return it.  It returns C<undef> if it fails.  The $url argument can
-be either a simple string or a reference to a URI object.
+be either a simple string or a reference to a URI::URL object.
 
 You will not be able to examine the response code or response headers
 (like 'Content-Type') when you are accessing the web using this
@@ -159,18 +159,15 @@ use HTTP::Status;
 push(@EXPORT, @HTTP::Status::EXPORT);
 
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.28.2.1 $ =~ /(\d+)\.(\d+)/);
-$FULL_LWP++ if grep {lc($_) eq "http_proxy"} keys %ENV;
+$VERSION = sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
+$FULL_LWP++ if grep {$_ eq "http_proxy"} keys %ENV;
 
 
 sub import
 {
     my $pkg = shift;
     my $callpkg = caller;
-    if (grep $_ eq '$ua', @_) {
-	$FULL_LWP++;
-	_init_ua();
-    }
+    $FULL_LWP++ if grep $_ eq '$ua', @_;
     Exporter::export($pkg, $callpkg, @_);
 }
 
@@ -220,8 +217,8 @@ sub head ($)
 	return $response unless wantarray;
 	return ($response->header('Content-Type'),
 		$response->header('Content-Length'),
-		HTTP::Date::str2time($response->header('Last-Modified')),
-		HTTP::Date::str2time($response->header('Expires')),
+		str2time($response->header('Last-Modified')),
+		str2time($response->header('Expires')),
 		$response->header('Server'),
 	       );
     }
@@ -311,8 +308,8 @@ sub _trivial_http_get
 
    if ($buf =~ m,^HTTP/\d+\.\d+\s+(\d+)[^\012]*\012,) {
        my $code = $1;
-       #print "CODE=$code\n$buf\n";
-       if ($code =~ /^30[1237]/ && $buf =~ /\012Location:\s*(\S+)/) {
+       #print "CODE=$code\n";
+       if ($code =~ /^3/ && $buf =~ /\012Location:\s*(\S+)/) {
            # redirect
            my $url = $1;
            return undef if $loop_check{$url}++;
